@@ -1,4 +1,4 @@
-/* 
+/*
  * Copyright (C) 2009 Piotr Pokora <piotrek.pokora@gmail.com>
  * Copyright (C) 2009 Cornelius Hald <hald@icandy.de>
  *
@@ -6,12 +6,12 @@
  * under the terms of the GNU Lesser General Public License as published
  * by the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -28,7 +28,7 @@ static GObjectClass *parent_class = NULL;
 static GObject *
 _conboy_note_constructor (GType type,
 		guint n_construct_properties,
-		GObjectConstructParam *construct_properties) 
+		GObjectConstructParam *construct_properties)
 {
 	GObject *object = (GObject *)
 		G_OBJECT_CLASS (parent_class)->constructor (type,
@@ -39,10 +39,10 @@ _conboy_note_constructor (GType type,
 	note->guid = NULL;
 	note->title = NULL;
 	note->content = NULL;
-	
+
 	note->note_version = 0.3;
 	note->content_version = 0.1;
-	
+
 	return G_OBJECT(object);
 }
 
@@ -50,9 +50,9 @@ static void
 _conboy_note_class_dispose(GObject *object)
 {
 	ConboyNote *self = CONBOY_NOTE(object);
-	
+
 	g_printerr("Dispose Note: %s\n", self->title);
-	
+
 	g_free((gchar*)self->guid);
 	self->guid = NULL;
 
@@ -61,7 +61,7 @@ _conboy_note_class_dispose(GObject *object)
 
 	g_free((gchar*)self->content);
 	self->content = NULL;
-	
+
 	conboy_note_clear_tags(self);
 
 	parent_class->dispose(object);
@@ -90,7 +90,7 @@ static void
 conboy_note_get_property (GObject *object, guint id, GValue *value, GParamSpec *spec)
 {
 	ConboyNote *note = CONBOY_NOTE(object);
-	
+
 	switch (id)
 	{
 		case PROP_GUID:
@@ -148,7 +148,7 @@ static void
 conboy_note_set_property (GObject *object, guint id, const GValue *value, GParamSpec *spec)
 {
 	ConboyNote *note = CONBOY_NOTE(object);
-	
+
 	switch (id)
 	{
 		case PROP_GUID:
@@ -215,73 +215,73 @@ _conboy_note_class_init (ConboyNoteClass *klass, gpointer g_class_data)
 	object_class->dispose = _conboy_note_class_dispose;
 	object_class->get_property = conboy_note_get_property;
 	object_class->set_property = conboy_note_set_property;
-	
+
 	/*
 	 * Create and install properties
 	 */
 
 	GParamSpec *spec;
-	
+
 	spec = g_param_spec_string("guid", "GUID",
 			"The global unique identifier", NULL, G_PARAM_READWRITE);
 	g_object_class_install_property(object_class, PROP_GUID, spec);
-	
+
 	spec = g_param_spec_string("title", "Title",
-			"The title of the note", NULL, G_PARAM_READWRITE);	
+			"The title of the note", NULL, G_PARAM_READWRITE);
 	g_object_class_install_property(object_class, PROP_TITLE, spec);
-	
+
 	spec = g_param_spec_string("content", "Content",
-			"XML representation of the notes content", NULL, G_PARAM_READWRITE);	
+			"XML representation of the notes content", NULL, G_PARAM_READWRITE);
 	g_object_class_install_property(object_class, PROP_CONTENT, spec);
-	
+
 	spec = g_param_spec_uint("create-date", "Create date",
-			"The date of note creation", 0, G_MAXINT, 0, G_PARAM_READWRITE);	
+			"The date of note creation", 0, G_MAXINT, 0, G_PARAM_READWRITE);
 	g_object_class_install_property(object_class, PROP_CREATE_DATE, spec);
-	
+
 	spec = g_param_spec_uint("change-date", "Change date",
-			"The date of the last change", 0, G_MAXINT, 0, G_PARAM_READWRITE);	
+			"The date of the last change", 0, G_MAXINT, 0, G_PARAM_READWRITE);
 	g_object_class_install_property(object_class, PROP_CHANGE_DATE, spec);
-	
+
 	spec = g_param_spec_uint("metadata-change-date", "Metadata change date",
-			"The date of the last metadata change", 0, G_MAXINT, 0, G_PARAM_READWRITE);	
+			"The date of the last metadata change", 0, G_MAXINT, 0, G_PARAM_READWRITE);
 	g_object_class_install_property(object_class, PROP_METADATA_CHANGE_DATE, spec);
-	
+
 	spec = g_param_spec_int("cursor-position", "Cursor position",
-			"The current cursor position", 0, G_MAXINT, 0, G_PARAM_READWRITE);	
+			"The current cursor position", 0, G_MAXINT, 0, G_PARAM_READWRITE);
 	g_object_class_install_property(object_class, PROP_CURSOR_POSITION, spec);
-	
+
 	spec = g_param_spec_boolean("pinned", "Pinned",
-			"Whether or not the note is pinned (sticky)", FALSE, G_PARAM_READWRITE);	
+			"Whether or not the note is pinned (sticky)", FALSE, G_PARAM_READWRITE);
 	g_object_class_install_property(object_class, PROP_PINNED, spec);
-	
+
 	spec = g_param_spec_boolean("open-on-startup", "Open on startup",
 			"Whether or not the note should be opened on startup", FALSE, G_PARAM_READWRITE);
 	g_object_class_install_property(object_class, PROP_OPEN_ON_STARTUP, spec);
-	
+
 	spec = g_param_spec_int("width", "Window width",
-			"The width of the note window", 0, G_MAXINT, 0, G_PARAM_READWRITE);	
+			"The width of the note window", 0, G_MAXINT, 0, G_PARAM_READWRITE);
 	g_object_class_install_property(object_class, PROP_WIDTH, spec);
-	
+
 	spec = g_param_spec_int("height", "Window height",
-			"The height of the note window", 0, G_MAXINT, 0, G_PARAM_READWRITE);	
+			"The height of the note window", 0, G_MAXINT, 0, G_PARAM_READWRITE);
 	g_object_class_install_property(object_class, PROP_HEIGHT, spec);
-	
+
 	spec = g_param_spec_int("x", "Window x position",
-			"The x position of the note window", 0, G_MAXINT, 0, G_PARAM_READWRITE);	
+			"The x position of the note window", 0, G_MAXINT, 0, G_PARAM_READWRITE);
 	g_object_class_install_property(object_class, PROP_X, spec);
-	
+
 	spec = g_param_spec_int("y", "Window y position",
-			"The y position of the note window", 0, G_MAXINT, 0, G_PARAM_READWRITE);	
+			"The y position of the note window", 0, G_MAXINT, 0, G_PARAM_READWRITE);
 	g_object_class_install_property(object_class, PROP_Y, spec);
-	
+
 	spec = g_param_spec_double("note-version", "Note version",
-			"The version of the note", 0, G_MAXDOUBLE, 0.3, G_PARAM_READWRITE);	
+			"The version of the note", 0, G_MAXDOUBLE, 0.3, G_PARAM_READWRITE);
 	g_object_class_install_property(object_class, PROP_NOTE_VERSION, spec);
-	
+
 	spec = g_param_spec_double("content-version", "Content version",
-			"The version notes content", 0, G_MAXDOUBLE, 0.1, G_PARAM_READWRITE);	
+			"The version notes content", 0, G_MAXDOUBLE, 0.1, G_PARAM_READWRITE);
 	g_object_class_install_property(object_class, PROP_CONTENT_VERSION, spec);
-	
+
 }
 
 GType
@@ -324,7 +324,10 @@ note_get_uuid()
 ConboyNote*
 conboy_note_new()
 {
-	return g_object_new(CONBOY_TYPE_NOTE, "guid", note_get_uuid(), NULL);
+	gchar *guid = note_get_uuid();
+	ConboyNote *note = g_object_new(CONBOY_TYPE_NOTE, "guid", guid, NULL);
+	g_free(guid);
+	return note;
 }
 
 ConboyNote*
@@ -344,7 +347,7 @@ conboy_note_new_with_title (const gchar* title)
 			_("Describe your new note here."));
 
 	g_object_set(note, "title", title, "content", xml, NULL);
-	
+
 	return note;
 }
 
@@ -353,9 +356,9 @@ conboy_note_add_tag(ConboyNote* note, const gchar* tag)
 {
 	g_return_if_fail(note != NULL);
 	g_return_if_fail(tag != NULL);
-	
+
 	g_return_if_fail(CONBOY_IS_NOTE(note));
-	
+
 	note->tags = g_list_append(note->tags, g_strdup(tag));
 }
 
@@ -365,7 +368,7 @@ conboy_note_clear_tags(ConboyNote* note)
 	g_return_if_fail(note != NULL);
 	g_return_if_fail(CONBOY_IS_NOTE(note));
 	g_return_if_fail(note->tags != NULL);
-	
+
 	GList *tags = note->tags;
 	while (tags != NULL) {
 		g_free(tags->data);
@@ -381,8 +384,83 @@ conboy_note_get_tags(ConboyNote* note)
 {
 	g_return_val_if_fail(note != NULL, NULL);
 	g_return_val_if_fail(CONBOY_IS_NOTE(note), NULL);
-	
+
 	return note->tags;
 }
 
+/**
+ * Creates an almost exact deep copy of a note.
+ */
+ConboyNote*
+conboy_note_copy (ConboyNote* note)
+{
+	g_return_val_if_fail(note != NULL, NULL);
+	g_return_val_if_fail(CONBOY_IS_NOTE(note), NULL);
 
+	ConboyNote *copy = conboy_note_new_with_guid(note->guid);
+
+	g_object_set(copy,
+			"title", note->title,
+			"content", note->content,
+			"create-date", note->create_date,
+			"change-date", note->last_change_date,
+			"metadata-change-date", note->last_metadata_change_date,
+			"content-version", note->content_version,
+			"cursor-position", note->cursor_position,
+			"note-version", note->note_version,
+			"x", note->x,
+			"y", note->y,
+			"width", note->width,
+			"height", note->height,
+			"open-on-startup", note->open_on_startup,
+			"pinned", note->pinned,
+			NULL);
+
+	GList *tags = note->tags;
+	while (tags) {
+		gchar *tag = tags->data;
+		conboy_note_add_tag(copy, tag);
+		tags = tags->next;
+	}
+
+	return copy;
+}
+
+/**
+ * Changes the title of a note. Affected are the title property,
+ * as well as the first line in the content. Title is automatically
+ * escaped.
+ */
+void
+conboy_note_rename (ConboyNote *note, const gchar *new_title)
+{
+	g_return_if_fail(note != NULL);
+	g_return_if_fail(CONBOY_IS_NOTE(note));
+
+	gchar *esc_title = g_markup_escape_text(new_title, -1);
+	gchar **parts = g_strsplit(note->content, "\n", 2);
+	gchar *new_content = g_strconcat("<note-content version=\"0.1\">", esc_title, "\n", parts[1], NULL);
+
+	g_object_set(note,
+			"title", new_title,
+			"content", new_content,
+			NULL);
+
+	g_free(new_content);
+	g_free(esc_title);
+	g_strfreev(parts);
+}
+
+/**
+ * Generates a new GUID and sets it for the provided note.
+ */
+void
+conboy_note_renew_guid (ConboyNote *note)
+{
+	g_return_if_fail(note != NULL);
+	g_return_if_fail(CONBOY_IS_NOTE(note));
+
+	gchar *guid = note_get_uuid();
+	g_object_set(note, "guid", guid, NULL);
+	g_free(guid);
+}
