@@ -1,4 +1,4 @@
-/* 
+/*
  * Copyright (C) 2009 Piotr Pokora <piotrek.pokora@gmail.com>
  * Copyright (C) 2009 Cornelius Hald <hald@icandy.de>
  *
@@ -6,12 +6,12 @@
  * under the terms of the GNU Lesser General Public License as published
  * by the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -36,11 +36,11 @@ typedef struct _ConboyNoteClass ConboyNoteClass;
 
 struct _ConboyNote {
 	GObject parent;
-	
+
 	/* <private> */
 	/* identifiers */
 	const gchar *guid;
-	
+
 	/* note */
 	const gchar *content;
 	const gchar *title;
@@ -59,7 +59,7 @@ struct _ConboyNote {
 	gint height;
 	gint x;
 	gint y;
-	
+
 	/* version */
 	gdouble note_version;
 	gdouble content_version;
@@ -67,9 +67,9 @@ struct _ConboyNote {
 
 struct _ConboyNoteClass {
 	GObjectClass parent;
-	
+
 	/* signals */
-	
+
 };
 
 /*
@@ -85,6 +85,9 @@ void         conboy_note_remove_tag     (ConboyNote* note, const gchar*);
 void         conboy_note_clear_tags     (ConboyNote* note);
 GList*       conboy_note_get_tags       (ConboyNote* note);
 
+ConboyNote*  conboy_note_copy           (ConboyNote* note);
+void         conboy_note_rename         (ConboyNote *note, const gchar *new_title);
+void         conboy_note_renew_guid     (ConboyNote *note);
 
 
 #endif /* CONBOY_NOTE_H */
